@@ -219,7 +219,19 @@ void Rainbow::HttpClient::request_thread ()
 			break; // last header
 		if (first_line.size() == 0) {
 			first_line = line;
-			goto header_loop;
+			
+			// determine status code
+			string::size_type s_p = first_line.find(' ');
+			if (s_p != string::npos && first_line.substr(s_p + 1, 3) == "200")
+				goto header_loop;
+
+			// it's not 200, so there must be an error
+			close(net_sock);
+			net_sock = 0;
+			logmsg << "HttpClient: Status failure (" << first_line.substr(s_p + 1, 3) << ")" << endl;
+			success = false;
+			my_signal_done();
+			return;
 		}
 		string::size_type colon = line.find(": ");
 		if (colon == string::npos)
@@ -443,8 +455,6 @@ void Rainbow::HttpClient::send_signal_percent ()
 	percent_mutex.lock();
 	unsigned int p = percent;
 	percent_mutex.unlock();
-	if (p % 10 == 0)
-		logmsg << "HttpClient: " << p << "% done download of \"" << remote_file << "\" from " << requested_host << endl;
 
 	signal_download_percent(p);
 }
